instancelib.feature\_extraction.textsklearn module
==================================================

.. automodule:: instancelib.feature_extraction.textsklearn
   :members:
   :undoc-members:
   :show-inheritance:
